Port
====

.. _Port_Subtypes:

*Subclasses:*

.. toctree::
   :maxdepth: 1

   InputPort
   ParameterPort
   OutputPort
   ModulatorySignal

.. automodule:: psyneulink.core.components.ports.port
   :members:
   :exclude-members: random, update, Parameters

